@@ -21,6 +21,7 @@ from starplot.plotters import (
     DsoPlotterMixin,
     MilkyWayPlotterMixin,
     GradientBackgroundMixin,
+    LegendPlotterMixin,
 )
 from starplot.styles import (
     PlotStyle,
@@ -55,6 +56,7 @@ class HorizonPlot(
     DsoPlotterMixin,
     MilkyWayPlotterMixin,
     GradientBackgroundMixin,
+    LegendPlotterMixin,
 ):
     """Creates a new horizon plot.
 
@@ -378,6 +380,11 @@ class HorizonPlot(
                 label,
                 (x, patch_y + 0.027),
                 xycoords=self.ax.transAxes,
+                xytext=(
+                    style.label.offset_x * self.scale,
+                    style.label.offset_y * self.scale,
+                ),
+                textcoords="offset points",
                 **style.label.matplot_kwargs(self.scale),
                 clip_on=False,
             )
@@ -432,7 +439,6 @@ class HorizonPlot(
         label_style_kwargs.pop("ha")
 
         line_style_kwargs = style.line.matplot_kwargs()
-
         gridlines = self.ax.gridlines(
             draw_labels=show_labels,
             x_inline=False,
@@ -497,7 +503,7 @@ class HorizonPlot(
                     "|",
                     (x, -0.011 * self.scale),
                     xycoords=self.ax.transAxes,
-                    **self.style.gridlines.label.matplot_kwargs(self.scale / 2),
+                    **style.label.matplot_kwargs(self.scale / 2),
                 )
 
     @cache
