@@ -14,7 +14,12 @@ from starplot.mixins import ExtentMaskMixin
 from starplot.models import Star
 from starplot.observer import Observer
 from starplot.optics import Optic, Camera
-from starplot.plotters import StarPlotterMixin, DsoPlotterMixin, GradientBackgroundMixin
+from starplot.plotters import (
+    StarPlotterMixin,
+    DsoPlotterMixin,
+    GradientBackgroundMixin,
+    LegendPlotterMixin,
+)
 from starplot.styles import (
     PlotStyle,
     ObjectStyle,
@@ -37,6 +42,7 @@ class OpticPlot(
     StarPlotterMixin,
     DsoPlotterMixin,
     GradientBackgroundMixin,
+    LegendPlotterMixin,
 ):
     """Creates a new optic plot.
 
